server_client_20141209_135620

### config1 : test_client_isolation

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.44193100929 sec | 5.53578686714 sec

Error message: Did not properly handle faulty client

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.78 | 0.29 | 0.21 | 0.26 | 0.33 | 0.38 | 0.42 | 0.64 | 0.08
qps | 301.00 | 223.00 | 145.00 | 223.00 | 262.00 | 285.40 | 293.20 | 299.44 | 78.00

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.262
server1-perf | latency | mean lt 0.33 | 0.28980044843
server1-perf | qps | mean lt 7.0 | 223.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | None
client1-perf | latency | mean lt 35.0 | None
client1-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None